@@ -42,8 +42,10 @@
 #include <cc++/process.h>
 #ifdef	__BORLANDC__
 #include <stdio.h>
+#include <stdlib.h>
 #else
 #include <cstdio>
+#include <cstdlib>
 #endif
 #include "private.h"
 
@@ -1033,6 +1035,7 @@ void Thread::close()
 		if(priv) {
 #ifndef	WIN32
 			priv->_jtid = priv->_tid;
+			priv->_tid = 0;
 #else
 			priv->_active = false;
 #endif
