@@ -13,8 +13,7 @@ class SHATumblerTest : public CppUnit::TestFixture
   CPPUNIT_TEST_SUITE_END();
 protected:
 public:
-  void test()
-  {
-    SHATumbler<uint32> tumbler(1);
+  void test() {
+	SHATumbler<uint32> tumbler(1);
   }
 };
